# PublicationDate

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**year** | [**Year**](Year.md) |  | 
**month** | [**Month**](Month.md) |  | [optional] 
**day** | [**Day**](Day.md) |  | [optional] 
**media_type** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


